aboutsummaryrefslogtreecommitdiff
path: root/mesonbuild/dependencies/dev.py
diff options
context:
space:
mode:
Diffstat (limited to 'mesonbuild/dependencies/dev.py')
-rw-r--r--mesonbuild/dependencies/dev.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/mesonbuild/dependencies/dev.py b/mesonbuild/dependencies/dev.py
index 2be9be4..4a163ea 100644
--- a/mesonbuild/dependencies/dev.py
+++ b/mesonbuild/dependencies/dev.py
@@ -173,13 +173,13 @@ class LLVMDependency(ConfigToolDependency):
def _set_new_link_args(self):
"""How to set linker args for LLVM versions >= 3.9"""
- if (mesonlib.is_dragonflybsd() and not self.static and
- version_compare(self.version, '>= 4.0')):
- # llvm-config on DragonFly BSD for versions 4.0, 5.0, and 6.0 have
- # an error when generating arguments for shared mode linking, even
- # though libLLVM.so is installed, because for some reason the tool
- # expects to find a .so for each static library. This works around
- # that.
+ if ((mesonlib.is_dragonflybsd() or mesonlib.is_freebsd()) and not
+ self.static and version_compare(self.version, '>= 4.0')):
+ # llvm-config on DragonFly BSD and FreeBSD for versions 4.0, 5.0,
+ # and 6.0 have an error when generating arguments for shared mode
+ # linking, even though libLLVM.so is installed, because for some
+ # reason the tool expects to find a .so for each static library.
+ # This works around that.
self.link_args = self.get_config_value(['--ldflags'], 'link_args')
self.link_args.append('-lLLVM')
return